"""
    EMIL ClaimService

    The EMIL ClaimService API description  # noqa: E501

    The version of the OpenAPI document: 1.0
    Contact: kontakt@emil.de
    Generated by: https://openapi-generator.tech
"""


import unittest

import eis.claim
from eis.claim.api.claims_api import ClaimsApi  # noqa: E501


class TestClaimsApi(unittest.TestCase):
    """ClaimsApi unit test stubs"""

    def setUp(self):
        self.api = ClaimsApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_create_claim(self):
        """Test case for create_claim

        Create the claim  # noqa: E501
        """
        pass

    def test_delete_claim(self):
        """Test case for delete_claim

        Delete the claim  # noqa: E501
        """
        pass

    def test_get_claim(self):
        """Test case for get_claim

        Retrieve the claim  # noqa: E501
        """
        pass

    def test_get_claim_regulation_summary(self):
        """Test case for get_claim_regulation_summary

        Retrieve the claim regulation summary  # noqa: E501
        """
        pass

    def test_list_claims(self):
        """Test case for list_claims

        List claims  # noqa: E501
        """
        pass

    def test_patch_claim(self):
        """Test case for patch_claim

        Patch the claim  # noqa: E501
        """
        pass

    def test_update_claim(self):
        """Test case for update_claim

        Update the claim  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
