"""
    EMIL ClaimService

    The EMIL ClaimService API description  # noqa: E501

    The version of the OpenAPI document: 1.0
    Contact: kontakt@emil.de
    Generated by: https://openapi-generator.tech
"""


import unittest

import eis.claim
from eis.claim.api.claim_statuses_api import ClaimStatusesApi  # noqa: E501


class TestClaimStatusesApi(unittest.TestCase):
    """ClaimStatusesApi unit test stubs"""

    def setUp(self):
        self.api = ClaimStatusesApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_create_claim_status(self):
        """Test case for create_claim_status

        Create the claim status  # noqa: E501
        """
        pass

    def test_delete_claim_status(self):
        """Test case for delete_claim_status

        Delete the claim status  # noqa: E501
        """
        pass

    def test_get_claim_status(self):
        """Test case for get_claim_status

        Retrieve the claim status  # noqa: E501
        """
        pass

    def test_list_claim_statuses(self):
        """Test case for list_claim_statuses

        List claim statuses  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
